@@ -20,6 +20,7 @@
 #include <QAction>
 #include <QGroupBox>
 #include <QPainter>
+#include <QTimeLine>
 
 #include <KConfigDialog>
 #include <KMessageBox>
@@ -50,6 +51,8 @@ Q_DECLARE_METATYPE( Plasma::DataEngine::Data )
 FlickrOP::FlickrOP( QObject* p_parent, const QVariantList& p_args )
 : Applet( p_parent, p_args )
 , m_engine( 0 )
+, m_timeline( 0 )
+, m_alpha( 1.0 )
 , m_authenticated( false )
 , m_cluster_chosen( false )
 , m_location_chosen( false )
@@ -64,6 +67,8 @@ FlickrOP::FlickrOP( QObject* p_parent, const QVariantList& p_args )
 , m_show_background( true )
 , m_soft_borders( false )
 {
+  KGlobal::locale()->insertCatalog("flickrop");
+  
   setBackgroundHints( Applet::NoBackground );
   setAspectRatioMode( KeepAspectRatio );
   setHasConfigurationInterface( true );
@@ -86,6 +91,10 @@ FlickrOP::~FlickrOP()
 
 void FlickrOP::init()
 {
+  m_timeline = new QTimeLine( 1000, this );
+  m_timeline->setCurveShape( QTimeLine::EaseInCurve );
+  connect( m_timeline, SIGNAL( valueChanged( qreal ) ), SLOT( setAlpha( qreal ) ) );
+
   m_nextPhoto = new QAction( SmallIcon("system-run"), i18n("Ne&xt Photo"), this );
   m_nextPhoto->setEnabled( false );
   m_actions.append( m_nextPhoto );
@@ -135,7 +144,17 @@ void FlickrOP::paintInterface ( QPainter *p_painter, const QStyleOptionGraphicsI
     paintCache( p_option, p_contentsRect );
   }
 
-  p_painter->drawPixmap( p_contentsRect, m_pixmapCache, p_contentsRect );
+  if ( !m_oldPixmapCache.isNull() )
+  {
+    p_painter->setOpacity( m_alpha );
+    p_painter->drawPixmap( p_contentsRect, m_pixmapCache, p_contentsRect );
+    p_painter->setOpacity( 1.0 - m_alpha );
+    p_painter->drawPixmap( p_contentsRect, m_oldPixmapCache, p_contentsRect );
+  }
+  else
+  {
+    p_painter->drawPixmap( p_contentsRect, m_pixmapCache, p_contentsRect );
+  }
 }
 
 void FlickrOP::paintCache ( const QStyleOptionGraphicsItem *p_option, const QRect &p_contentsRect )
@@ -310,7 +329,7 @@ void FlickrOP::readConfig()
 
   sendConfigurationToEngine();
   setBackgroundHints( m_show_background ? Applet::TranslucentBackground : Applet::NoBackground );
-  m_pixmapCache = QPixmap();
+  resetPixmapCache();
   update();
 }
 
@@ -666,13 +685,22 @@ void FlickrOP::dataUpdated( const QString &p_sourceName, const DataEngine::Data
     m_error.clear();
     m_photo = p_data.value( "flickr" ).value<Photo>();
     m_pixmapPhoto.load( m_photo.filename, "JPG" );
-    m_pixmapCache = QPixmap();
+    resetPixmapCache();
     m_nextPhoto->setEnabled( true );
     m_visitAuthor->setEnabled( true );
     m_visitPhotoPage->setEnabled( true );
     m_visitAuthorPhotos->setEnabled( true );
     m_markFavorite->setEnabled( m_authenticated );
-    update();
+    if ( m_oldPixmapCache.isNull() )
+    {
+      m_alpha = 1.0;
+      update();
+    }
+    else
+    {
+      // there's an old pixmap available, do a nice fadeout
+      m_timeline->start();
+    }
   }
 }
 
@@ -828,4 +856,16 @@ void FlickrOP::locationChosen()
   setOkButton();
 }
 
+void FlickrOP::setAlpha( qreal p_value )
+{
+  m_alpha = p_value;
+  update();
+}
+
+void FlickrOP::resetPixmapCache()
+{
+  m_oldPixmapCache = m_pixmapCache;
+  m_pixmapCache = QPixmap();
+}
+
 K_EXPORT_PLASMA_APPLET(flickrop, FlickrOP)
